Cloudhealth REST Client
=======================

This is a Python REST Client for the Cloudhealth service.

## Installation

```
git clone https://github.com/albertonarro/cloudhealth-client.git
```

## Python Usage

```python
from cloudhealth-client import client

client = client.CloudHealth(api_key='123456789qwerty')

```
## Contributions.

